@@ -23,7 +23,7 @@ See the file COPYING for details.
 #include "debug.h"
 #include "auth_all.h"
 #include "stringtools.h"
-#include "xmalloc.h"
+#include "xxmalloc.h"
 #include "fast_popen.h"
 
 // Defined by Li
