@@ -634,6 +634,18 @@ digest into a human readable form.
 
 INT64_T chirp_reli_md5(const char *host, const char *path, unsigned char digest[16], time_t stoptime);
 
+/** Set replication factor.
+Sets the number of replicas desired for the indicated file or for all newly created files.
+This only has an effect if the server backend supports replication, currently only with HDFS.
+@param host The name and port of the Chirp server to access.
+@param path The pathname of the file to modify.  If the pathname is <tt>"@@@"</tt>, then this call sets the replication factor for all files created by this process.
+@param nreps The number of replicas desired.  Zero indicates the server should use the default replication value. 
+@param stoptime The absolute time at which to abort.
+@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
+*/
+
+INT64_T chirp_reli_setrep(const char *host, const char *path, int nreps, time_t stoptime );
+
 /** Set the debug options on the remote server.
 @param host The name and port of the Chirp server to access.
 @param flag A debug flag to set on the server. Pass NULL to not change. Pass "clear" to clear.
@@ -711,159 +723,14 @@ INT64_T chirp_reli_mkalloc(const char *host, const char *path, INT64_T size, INT
 
 INT64_T chirp_reli_lsalloc(const char *host, const char *path, char *allocpath, INT64_T * total, INT64_T * inuse, time_t stoptime);
 
-/** Create a new access control group.
-Note that group is deleted by calling @ref chirp_reli_unlink on the group name.
-@param host The name and port of the server hosting the group.
-@param group The group name, which is simply a path on the server.
+/** Perform multiple I/O operations in bulk.
+This operation will perform multiple I/O operations by pipelining the requests
+and the results. It is the most efficient way to perform multiple reads
+and writes simultaneously, whether against one or many files.
+@param list An array of @ref chirp_bulkio structures, each describing one I/O operation.
+@param count The number of entries in the list.
 @param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_group_create(const char *host, char *group, time_t stoptime);
-
-/** List members of an access control group.
-@param host The name and port of the server hosting the group.
-@param group The group name, which is simple a path on the server.
-@param callback A function to call for each member of the group.
-@param arg An optional convenience pointer to pass to the callback.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_group_list(const char *host, const char *group, chirp_dir_t callback, void *arg, time_t stoptime);
-
-/** Add a user to a group.
-@param host The name and port of the server hosting the group.
-@param group The group name, which is simple a path on the server.
-@param user The subject name to add to the group.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_group_add(const char *host, char *group, char *user, time_t stoptime);
-
-/** Remove a user from a group.
-@param host The name and port of the server hosting the group.
-@param group The group name, which is simple a path on the server.
-@param user The subject name to remove from the group.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-*/
-
-INT64_T chirp_reli_group_remove(const char *host, char *group, char *user, time_t stoptime);
-
-/** Test membership in a group.
-@param host The name and port of the server hosting the group.
-@param group The group name, which is simple a path on the server.
-@param user The subject name to remove from the group.
-@param stoptime The absolute time at which to abort.
-@return Greater than zero if the user is a member of the group, zero is the user is not a member of a group, less than zero if there is a failure to access the group.
-*/
-
-INT64_T chirp_reli_group_lookup(const char *host, const char *group, const char *user, time_t stoptime);
-
-/* Note that these functions are not documented because they are only used for inter-server communications. */
-INT64_T chirp_reli_group_cache_update(const char *host, const char *group, time_t mod_time, time_t stoptime);
-INT64_T chirp_reli_group_policy_set(const char *host, char *group, unsigned long int file_duration, unsigned long int dec_duration, time_t stoptime);
-INT64_T chirp_reli_group_policy_get(const char *host, const char *group, int *policy, int *file_duration, int *dec_duration, time_t stoptime);
-
-/** Create a new active storage job.
-This function creates a new job with a given command line and the explicitly names the current working directory and standard I/O files.
-A unique job identifier will be returned, which must be given to @ref chirp_reli_job_commit, which will permit the job to run.
-@param host The name and port of the Chirp server to access.
-@param cwd The initial working directory of the job.
-@param input A file to use as the standard input stream, or "-" for none.
-@param output A file to use as the standard output stream, or "-" for none.
-@param error A file to use as the standard error stream, or "-" for none.
-@param cmdline The command line to execute, beginning with the path of the executable.
-@param stoptime The absolute time at which to abort.
-@return On success, returns a unique job identifier.  On failure, returns less than zero and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_begin(const char *host, const char *cwd, const char *input, const char *output, const char *error, const char *cmdline, time_t stoptime);
-
-/** Commit an active storage job.
-A job created by @ref chirp_reli_job_begin is not allowed to run until it is committed by calling @ref chirp_reli_job_commit.
-This is called a <i>two phase commit</i> and is necessary to prevent runaway jobs of which the caller does not know the job ID.
-After this function is called, the job is free to run within the constraints of the local scheduler.
-@param host The name and port of the Chirp server to access.
-@param jobid The job identifier.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_commit(const char *host, INT64_T jobid, time_t stoptime);
-
-/** Get status of an active storage job.
-This function will obtain the detailed status of an active storage job, optionally waiting until it is complete.
-If wait_time is zero, then the job's status will be immediately returned.
-If wait_time is greater than zero, then this function will wait until the job reaches a completed state,
-or the wait_time expires.
-<b>Note that stoptime must be greater than waittime, otherwise you will never receive a response.</b>
-@param host The name and port of the Chirp server to access.
-@param jobid The job identifier.
-@param state A pointer to a buffer to be filled with the job's current states.
-@param wait_time The maximum time to wait for the job to complete.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_wait(const char *host, INT64_T jobid, struct chirp_job_state *state, int wait_time, time_t stoptime);
-
-/** Kill an active storage job.
-Forces the named job into the @ref CHIRP_JOB_STATE_KILLED state.
-The job record must still be removed by calling @ref chirp_reli_job_remove.
-The caller must be the owner of this job.
-@param host The name and port of the Chirp server to access.
-@param jobid The job identifier.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_kill(const char *host, INT64_T jobid, time_t stoptime);
-
-/** Remove an active storage job.
-Deletes the record and all other state associated with an active storage job.
-If the job is not yet complete, it will be killed first.
-The caller must be the owner of this job.
-@param host The name and port of the Chirp server to access.
-@param jobid The job identifier.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_remove(const char *host, INT64_T jobid, time_t stoptime);
-
-/** List all active storage jobs.
-Returns status about all known jobs on a server, regardless of their owner or state.
-@param host The name and port of the Chirp server to access.
-@param callback The function to be called for each job in the listing.
-@param arg An optional convenience pointer passed to the callback.
-@param stoptime The absolute time at which to abort.
-@return On success, returns greater than or equal to zero.  On failure, returns less than zero  and sets errno.
-@see chirp_reli_job_begin, chirp_reli_job_commit, chirp_reli_job_wait, chirp_reli_job_list, chirp_reli_job_kill, chirp_reli_job_remove
-*/
-
-INT64_T chirp_reli_job_list(const char *host, chirp_joblist_t callback, void *arg, time_t stoptime);
-
-/** Perform multiple I/O operations simultaneously.
-This call invokes any number of I/O operations simultaneously,
-using pipelining and parallelism to complete quickly.
-Multiple operations may affect a single host, multiple hosts,
-or a mix of the two.  The list of operations is given by
-an array of @ref chirp_bulkio structures, each of which specifies
-an individual operation from @ref chirp_reli.h.  Note that only
-a select few operations are available through this interface.
-Future versions of the API may be more complete.
-@param list The list of operations to be performed.
-@param count The number of entries in list.
-@param stoptime The absolute time at which to abort.
-@returns On success, returns greater than or equal to zero.  On failure, returns less than zero and sets errno appropriately.  Note that "success" means all the operations were successfully dispatched.  Each individual operation will have it success or failure and errno recorded in the corresponding @ref chirp_bulkio structure.
+@return If all operations in the array succeed, this function will return greater than or equal to zero.  If one or more operations fail, this function will return less than zero.  The result of each individual operation may be determined by examining the result and errnum fields set in each @ref chirp_bulkio structure.
 */
 
 INT64_T chirp_reli_bulkio(struct chirp_bulkio *list, int count, time_t stoptime);
