@@ -33,7 +33,7 @@ See the file COPYING for details.
 #include "catalog_server.h"
 #include "domain_name_cache.h"
 #include "list.h"
-#include "xmalloc.h"
+#include "xxmalloc.h"
 #include "md5.h"
 #include "load_average.h"
 #include "memory_info.h"
@@ -588,6 +588,7 @@ int main(int argc, char *argv[])
 	}
 
 	link = link_serve_address(listen_on_interface, port);
+
 	if(!link) {
 		if(listen_on_interface) {
 			fatal("couldn't listen on interface %s port %d: %s", listen_on_interface, port, strerror(errno));
