@@ -10,12 +10,12 @@ prepare()
 {
     mkdir foo
     ln -s ..//.//./..///foo/ foo/foo
-    port=`find_free_port`
-    ../src/chirp_server -r $PWD/foo -p $port &
+    ../src/chirp_server -r $PWD/foo -Z $PORT_FILE &
+    # give the server a little time to write the port file
+    sleep 5
     pid=$!
 
     if ps ux | awk '{print $2}' | grep "^$pid$"; then
-	echo $port> $PORT_FILE
 	echo $pid > $PID_FILE
 	exit 0
     else
@@ -42,6 +42,7 @@ cd _test
 ls
 put /etc/hosts hosts.txt
 cat hosts.txt
+md5 hosts.txt
 getacl
 localpath hosts.txt
 exit
