@@ -5,5 +5,9 @@ This software is distributed under the GNU General Public License.
 See the file COPYING for details.
 */
 
- int auth_kerberos_register();
+#ifndef AUTH_KERBEROS_H
+#define AUTH_KERBEROS_H
 
+int auth_kerberos_register(void);
+
+#endif
