@@ -27,7 +27,7 @@ typedef enum {
 	BATCH_QUEUE_TYPE_CONDOR,              /**< Batch jobs will be sent to Condor pool. */
 	BATCH_QUEUE_TYPE_SGE,	              /**< Batch jobs will be sent to Sun Grid Engine. */
 	BATCH_QUEUE_TYPE_MOAB,                /**< Batch jobs will be sent to the Moab Workload Manager. */
-	BATCH_QUEUE_TYPE_GRID,                /**< Batch jobs will be sent to a user-defined grid manager. */
+	BATCH_QUEUE_TYPE_CLUSTER,                /**< Batch jobs will be sent to a user-defined cluster manager. */
 	BATCH_QUEUE_TYPE_WORK_QUEUE,          /**< Batch jobs will be sent to the Work Queue. */
 	BATCH_QUEUE_TYPE_WORK_QUEUE_SHAREDFS, /**< Batch jobs will be sent to the Work Queue, all files are stored on a shared filesystem. */
 	BATCH_QUEUE_TYPE_XGRID,	              /**< Batch jobs will be sent to the Xgrid. */
@@ -110,7 +110,7 @@ You must still call @ref batch_job_wait to wait for the removal to complete.
 int batch_job_remove(struct batch_queue *q, batch_job_id_t jobid);
 
 /** Converts a string into a batch queue type.
-@param str A string indicating the work queue type, which may be "unix", "condor", "sge", "wq", or "xgrid".
+@param str A string listing all of the known batch queue types (which changes over time.)
 @return The batch queue type corresponding to the string, or BATCH_QUEUE_TYPE_UNKNOWN if the string is invalid.
 */
 batch_queue_type_t batch_queue_type_from_string(const char *str);
