@@ -15,21 +15,24 @@ See the file COPYING for details.
 #include <stdio.h>
 #include <unistd.h>
 
-int clean_dir( const char *dirname, const char *delete_pattern )
+int clean_dir(const char *dirname, const char *delete_pattern)
 {
 	char subdir[PATH_MAX];
 	struct dirent *d;
 	DIR *dir;
 
 	dir = opendir(dirname);
-	if(!dir) return 0;
+	if(!dir)
+		return 0;
 
-	while((d=readdir(dir))) {
-		if(!strcmp(d->d_name,".")) continue;
-		if(!strcmp(d->d_name,"..")) continue;
-		sprintf(subdir,"%s/%s",dirname,d->d_name);
-		clean_dir(subdir,delete_pattern);
-		if(string_match(delete_pattern,d->d_name)) {
+	while((d = readdir(dir))) {
+		if(!strcmp(d->d_name, "."))
+			continue;
+		if(!strcmp(d->d_name, ".."))
+			continue;
+		sprintf(subdir, "%s/%s", dirname, d->d_name);
+		clean_dir(subdir, delete_pattern);
+		if(string_match(delete_pattern, d->d_name)) {
 			unlink(d->d_name);
 		}
 	}
