@@ -134,6 +134,10 @@ int link_nonblocking(struct link *link, int onoff)
 	return 1;
 }
 
+int link_buffer_empty(struct link *link) {
+	return link->buffer_length > 0 ? 0 : 1;
+}
+
 static int errno_is_temporary(int e)
 {
 	if(e == EINTR || e == EWOULDBLOCK || e == EAGAIN || e == EINPROGRESS || e == EALREADY || e == EISCONN) {
@@ -147,7 +151,13 @@ static int link_internal_sleep(struct link *link, struct timeval *timeout, int r
 {
 	int result;
 	struct pollfd pfd;
-	int msec = (timeout->tv_sec * 1000.0) + (timeout->tv_usec/1000.0);
+	int msec;
+
+	if(timeout) {
+		msec = (timeout->tv_sec * 1000.0) + (timeout->tv_usec/1000.0);
+	} else {
+		msec = -1;
+	}
 
 	while (1) {
 		pfd.fd = link->fd;
@@ -270,24 +280,50 @@ struct link *link_serve_address(const char *addr, int port)
 
 	link_window_configure(link);
 
-	if(addr != 0 || port != LINK_PORT_ANY) {
-
-		memset(&address, 0, sizeof(address));
+	memset(&address, 0, sizeof(address));
 #if defined(CCTOOLS_OPSYS_DARWIN)
-		address.sin_len = sizeof(address);
+	address.sin_len = sizeof(address);
 #endif
-		address.sin_family = AF_INET;
+	address.sin_family = AF_INET;
+
+	if(addr) {
+		string_to_ip_address(addr, (unsigned char *) &address.sin_addr.s_addr);
+	} else {
+		address.sin_addr.s_addr = htonl(INADDR_ANY);
+	}
+
+	int low = 1024;
+	int high = 32767;
+	if(port == 0) {
+		const char *lowstr = getenv("TCP_LOW_PORT");
+		if (lowstr)
+			low = atoi(lowstr);
+		const char *highstr = getenv("TCP_HIGH_PORT");
+		if (highstr)
+			high = atoi(highstr);
+	} else {
+		low = high = port;
+	}
+
+	if(high < low)
+		fatal("high port %d is less than low port %d in range", high, low);
+
+	for (port = low; port <= high; port++) {
 		address.sin_port = htons(port);
-
-		if(addr) {
-			string_to_ip_address(addr, (unsigned char *) &address.sin_addr.s_addr);
-		} else {
-			address.sin_addr.s_addr = htonl(INADDR_ANY);
-		}
-
 		success = bind(link->fd, (struct sockaddr *) &address, sizeof(address));
-		if(success < 0)
-			goto failure;
+		if(success == -1) {
+			if(errno == EADDRINUSE) {
+				//If a port is specified, fail!
+				if (low == high) { 
+					goto failure;
+				} else {	
+					continue;
+				}	
+			} else {
+				goto failure;
+			}
+		}
+		break;
 	}
 
 	success = listen(link->fd, 5);
@@ -384,21 +420,23 @@ struct link *link_connect(const char *addr, int port, time_t stoptime)
 		/* If the remote address can be found, then we are really connected. */
 		/* Also, on bsd-derived systems, failure to connect is indicated by a second connect returning EINVAL. */
 
-		if(result < 0 && !errno_is_temporary(errno)) {
-			if(errno == EINVAL)
-				errno = ECONNREFUSED;
-			break;
-		}
-
-		if(link_address_remote(link, link->raddr, &link->rport)) {
-
-			debug(D_TCP, "made connection to %s:%d", link->raddr, link->rport);
-
+		if(result < 0) {
+			if(!errno_is_temporary(errno)) {
+				if(errno == EINVAL)
+					errno = ECONNREFUSED;
+				break;
+			} else {
+				debug(D_TCP, "connection to %s:%d not made yet: %s", addr, port, strerror(errno));
+			}
+		} else {
+			if(link_address_remote(link, link->raddr, &link->rport)) {
+				debug(D_TCP, "made connection to %s:%d", link->raddr, link->rport);
 #ifdef CCTOOLS_OPSYS_CYGWIN
-			link_nonblocking(link, 1);
+				link_nonblocking(link, 1);
 #endif
-			return link;
-		}
+				return link;
+			}
+		} 
 	} while(link_sleep(link, stoptime, 0, 1));
 
 	debug(D_TCP, "connection to %s:%d failed (%s)", addr, port, strerror(errno));
