@@ -89,7 +89,9 @@ typedef enum {
 	NVPAIR_MODE_STRING,
 	NVPAIR_MODE_INTEGER,
 	NVPAIR_MODE_URL,
-	NVPAIR_MODE_METRIC
+	NVPAIR_MODE_METRIC,
+	NVPAIR_MODE_TIME,
+	NVPAIR_MODE_TIMESTAMP
 } nvpair_mode_t;
 
 typedef enum {
