@@ -33,6 +33,29 @@ timestamp_t timestamp_get()
 	return stamp;
 }
 
+int timestamp_fmt(char *buf, size_t size, const char *fmt, timestamp_t ts) 
+{
+	time_t tv_sec; 
+	struct tm *tp;
+
+	if(buf == NULL || size < 0) return 0;
+
+	tv_sec = ts / 1000000;
+
+#if defined (_XOPEN_SOURCE) || defined (_BSD_SOURCE) || defined (_SVID_SOURCE) || defined (_POSIX_SOURCE) || _POSIX_C_SOURCE >= 1 
+	struct tm t;
+	tp = localtime_r(&tv_sec, &t);
+#else
+	tp = localtime(&tv_sec);
+#endif
+
+	if(tp != NULL) {
+		return strftime(buf, size, fmt, tp);
+	}
+
+	return 0;
+}
+
 void timestamp_sleep(timestamp_t interval)
 {
 	struct timeval t;
