@@ -19,7 +19,6 @@ int pfs_dispatch64( struct pfs_process *p, INT64_T signum )
 
 #include "pfs_sysdeps64.h"
 #include "pfs_channel.h"
-#include "pfs_channel_cache.h"
 #include "pfs_process.h"
 #include "pfs_sys.h"
 #include "pfs_poll.h"
@@ -29,7 +28,7 @@ extern "C" {
 #include "tracer.h"
 #include "stringtools.h"
 #include "full_io.h"
-#include "xmalloc.h"
+#include "xxmalloc.h"
 #include "int_sizes.h"
 #include "macros.h"
 #include "debug.h"
@@ -137,7 +136,7 @@ static void decode_read( struct pfs_process *p, INT64_T entering, INT64_T syscal
 	char *local_addr;
 	
 	if(entering) {
-		if(!pfs_channel_alloc(length,&p->io_channel_offset)) {
+		if(!pfs_channel_alloc(0,length,&p->io_channel_offset)) {
 			divert_to_dummy(p,-ENOMEM);
 			return;
 		}
@@ -206,7 +205,7 @@ static void decode_write( struct pfs_process *p, INT64_T entering, INT64_T sysca
 	if(entering) {
 		void *uaddr = POINTER(args[1]);
 		INT64_T length = args[2];
-		if(!pfs_channel_alloc(length,&p->io_channel_offset)) {
+		if(!pfs_channel_alloc(0,length,&p->io_channel_offset)) {
 			divert_to_dummy(p,-ENOMEM);
 			return;
 		}
@@ -428,7 +427,7 @@ static void decode_stat( struct pfs_process *p, INT64_T entering, INT64_T syscal
 		}
 
 		if(p->syscall_result>=0) {
-			if(!pfs_channel_alloc(sizeof(kbuf),&p->io_channel_offset)) {
+			if(!pfs_channel_alloc(0,sizeof(kbuf),&p->io_channel_offset)) {
 				divert_to_dummy(p,-ENOMEM);
 			} else {
 				local_addr = pfs_channel_base() + p->io_channel_offset;
@@ -468,7 +467,7 @@ static void decode_statfs( struct pfs_process *p, INT64_T entering, INT64_T sysc
 		}
 
 		if(p->syscall_result>=0) {
-			if(!pfs_channel_alloc(sizeof(kbuf),&p->io_channel_offset)) {
+			if(!pfs_channel_alloc(0,sizeof(kbuf),&p->io_channel_offset)) {
 				divert_to_dummy(p,-ENOMEM);
 			} else {
 				local_addr = pfs_channel_base() + p->io_channel_offset;
@@ -838,7 +837,6 @@ static void decode_execve( struct pfs_process *p, INT64_T entering, INT64_T sysc
 	}
 }
 
-
 /*
 Memory mapped files are loaded into the channel,
 the whole file regardless of what portion is actually
@@ -848,53 +846,64 @@ mapped.  The channel cache keeps a reference count.
 static void decode_mmap( struct pfs_process *p, INT64_T syscall, INT64_T entering, INT64_T *args )
 {
 	if(entering) {
-		INT64_T addr, orig_length, prot, fd, flags;
-		pfs_size_t length, channel_offset, source_offset;
+		INT64_T addr, prot, fd, flags;
+		pfs_size_t length, source_offset, channel_offset;
 		INT64_T nargs[TRACER_ARGS_MAX];
 
 		memcpy(nargs,p->syscall_args,sizeof(p->syscall_args));
 
 		addr = nargs[0];
-		orig_length = nargs[1];
+		length = nargs[1];
 		prot = nargs[2];
 		flags = nargs[3];
 		fd = nargs[4];
-		//source_offset = nargs[5]*getpagesize();
 		source_offset = nargs[5];
 
-		debug(D_SYSCALL,"mmap addr=0x%x len=0x%x prot=0x%x flags=0x%x fd=%d offset=0x%llx",addr,orig_length,prot,flags,fd,source_offset);
+		debug(D_SYSCALL,"mmap addr=0x%x len=0x%x prot=0x%x flags=0x%x fd=%d offset=0x%llx",addr,length,prot,flags,fd,source_offset);
 
-		if(flags&MAP_ANONYMOUS) {
-			/* great, just do it. */
+		if(flags & MAP_ANONYMOUS) {
 			debug(D_SYSCALL,"mmap skipped b/c anonymous");
+			return;
+		}
+
+		channel_offset = pfs_mmap_create(fd,source_offset,length,prot,flags);
+		if(channel_offset<0) {
+			divert_to_dummy(p,-errno);
+			return;
+		}
+
+		nargs[3] = flags & ~MAP_DENYWRITE;
+		nargs[4] = pfs_channel_fd();
+		nargs[5] = channel_offset+source_offset;
+
+		debug(D_SYSCALL,"channel_offset=0x%llx source_offset=0x%llx total=0x%x",channel_offset,source_offset,nargs[5]);
+		debug(D_SYSCALL,"mmap changed: fd=%d offset=0x%x",nargs[4],nargs[5]);
+
+	      	tracer_args_set(p->tracer,p->syscall,nargs,6);
+		p->syscall_args_changed = 1;
+	} else {
+		/*
+		On exit from the system call, retrieve the logical address of
+		the mmap as returned to the application.  Then, update the 
+		mmap record that corresponds to the proper channel offset.
+		On failure, we must unmap the object, which will have a logical
+		address of zero because it was never set.
+		*/
+
+		if(args[3]&MAP_ANONYMOUS) {
+			// nothing to do
 		} else {
-			char file_name[PFS_PATH_MAX];
+			tracer_result_get(p->tracer,&p->syscall_result);
 
-			if(pfs_get_full_name(fd,file_name)!=0) {
-				debug(D_SYSCALL,"mmap failed name: %s",strerror(errno));
-				divert_to_dummy(p,-errno);
-				return;
-			}
-
-			if(pfs_channel_cache_alloc(file_name,fd,&length,&channel_offset)) {
-				nargs[3] = flags & ~MAP_DENYWRITE;
-				nargs[4] = pfs_channel_fd();
-				nargs[5] = channel_offset+source_offset;
-
-				debug(D_SYSCALL,"channel_offset=0x%llx source_offset=0x%llx total=0x%x",channel_offset,source_offset,nargs[5]);
-
-				debug(D_SYSCALL,"mmap changed: fd=%d offset=0x%x",nargs[4],nargs[5]);
-
-       				//nargs[5] = nargs[5] / getpagesize();
-	       			tracer_args_set(p->tracer,p->syscall,nargs,6);
-		       		p->syscall_args_changed = 1;
+			if(p->syscall_result!=-1) {
+				pfs_mmap_update(p->syscall_result,0);
 			} else {
-				debug(D_SYSCALL,"mmap failed cache: %s",strerror(errno));
-				divert_to_dummy(p,-errno);
-				return;
+				pfs_mmap_delete(0,0);
 			}
+
 		}
 	}
+
 }
 
 static INT64_T decode_ioctl_siocgifconf( struct pfs_process *p, INT64_T fd, INT64_T cmd, void *uaddr )
@@ -1677,19 +1686,12 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 			decode_mmap(p,p->syscall,entering,args);
 			break;
 
-		/*
-		XXX Incomplete but acceptable for now.
-		We permit the application to munmap whatever it likes.
-		This might be an anonymous map that we don't track,
-		or it could be file.  In the latter case, we would like
-		to decrement the reference count.  At the moment, we
-		can't tell the difference, nor can we reverse map the
-		application's space into our own address space.
-		Once loaded, mmaped objects just stay in until the
-		parent pfs process dies.
-		*/
 
 		case SYSCALL64_munmap:
+			if(entering) {
+				p->syscall_result = pfs_mmap_delete(args[0],args[1]);
+				divert_to_dummy(p,p->syscall_result);
+			}
 			break;
 
 		/*
@@ -2254,15 +2256,17 @@ static void decode_syscall( struct pfs_process *p, INT64_T entering )
 		case SYSCALL64_kill:
 		case SYSCALL64_tkill:
 			if(entering) {
-				debug(D_PROCESS,"tkill %d %d %d",args[0],args[1],args[2]);
-				pfs_process_raise(args[0],args[1],0);
+				debug(D_PROCESS,"%s %d %d %d",tracer_syscall64_name(p->syscall),args[0],args[1],args[2]);
+				p->syscall_result = pfs_process_raise(args[0],args[1],0);
+				divert_to_dummy(p,p->syscall_result);
 			}
 			break;
 
 		case SYSCALL64_tgkill:
 			if(entering) {
 				debug(D_PROCESS,"tgkill %d %d %d",args[0],args[1],args[2]);
-				pfs_process_raise(args[1],args[2],0);
+				p->syscall_result = pfs_process_raise(args[1],args[2],0);
+				divert_to_dummy(p,p->syscall_result);
 			}
 			break;
 
